Language definition and configuration for VB.NET.
VB.NET Language Definition
This module defines the VB.NET language configuration and settings for the Oaks framework.
Structs
- VbNet
Language - VB.NET language definition
Language definition and configuration for VB.NET.
This module defines the VB.NET language configuration and settings for the Oaks framework.