VbNetTokenType

Enum VbNetTokenType 

pub enum VbNetTokenType {
Show 137 variants Root, Expression, Whitespace, Newline, Identifier, IntegerLiteral, FloatLiteral, StringLiteral, CharLiteral, BooleanLiteral, DateLiteral, NothingLiteral, Namespace, Imports, Class, Interface, Structure, Enum, Module, Delegate, Event, Function, Sub, Property, Dim, Const, As, In, If, Then, Else, ElseIf, End, For, Each, To, Step, While, Do, Loop, Until, Select, Case, Default, With, Try, Catch, Finally, Throw, Exit, Continue, Next, Return, Me, MyBase, MyClass, New, Of, ByVal, ByRef, Optional, ParamArray, Public, Private, Protected, Friend, ProtectedFriend, Shared, MustInherit, NotInheritable, MustOverride, Overridable, Overrides, NotOverridable, MustOverrideReadOnly, ReadOnly, WriteOnly, Static, Partial, Async, Await, From, Where, Order, By, Group, Join, On, Into, Let, Overloads, Inherits, Implements, Get, Set, Equals, Statement, Plus, Minus, Star, Slash, Backslash, Percent, Caret, Equal, NotEqual, LessThan, LessEqual, GreaterThan, GreaterEqual, And, Or, Not, Xor, AndAlso, OrElse, Is, IsNot, Like, TypeOf, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Comma, Semicolon, Colon, Dot, Exclamation, Hash, Ampersand, LineComment, BlockComment, Error, Eof,
}
VB.NET token types

Variants



Root

Root node



Expression

Expression



Whitespace

Whitespace



Newline

Newline



Identifier

Identifier



IntegerLiteral

Integer literal



FloatLiteral

Float literal



StringLiteral

String literal



CharLiteral

Character literal



BooleanLiteral

Boolean literal



DateLiteral

Date literal



NothingLiteral

Nothing literal



Namespace

The ‘Namespace’ keyword



Imports

The ‘Imports’ keyword



Class

The ‘Class’ keyword



Interface

The ‘Interface’ keyword



Structure

The ‘Structure’ keyword



Enum

The ‘Enum’ keyword



Module

The ‘Module’ keyword



Delegate

The ‘Delegate’ keyword



Event

The ‘Event’ keyword



Function

The ‘Function’ keyword



Sub

The ‘Sub’ keyword



Property

The ‘Property’ keyword



Dim

The ‘Dim’ keyword



Const

The ‘Const’ keyword



As

The ‘As’ keyword



In

The ‘In’ keyword



If

The ‘If’ keyword



Then

The ‘Then’ keyword



Else

The ‘Else’ keyword



ElseIf

The ‘ElseIf’ keyword



End

The ‘End’ keyword



For

The ‘For’ keyword



Each

The ‘Each’ keyword



To

The ‘To’ keyword



Step

The ‘Step’ keyword



While

The ‘While’ keyword



Do

The ‘Do’ keyword



Loop

The ‘Loop’ keyword



Until

The ‘Until’ keyword



Select

The ‘Select’ keyword



Case

The ‘Case’ keyword



Default

The ‘Default’ keyword



With

The ‘With’ keyword



Try

The ‘Try’ keyword



Catch

The ‘Catch’ keyword



Finally

The ‘Finally’ keyword



Throw

The ‘Throw’ keyword



Exit

The ‘Exit’ keyword



Continue

The ‘Continue’ keyword



Next

The ‘Next’ keyword



Return

The ‘Return’ keyword



Me

The ‘Me’ keyword



MyBase

The ‘MyBase’ keyword



MyClass

The ‘MyClass’ keyword



New

The ‘New’ keyword



Of

The ‘Of’ keyword



ByVal

The ‘ByVal’ keyword



ByRef

The ‘ByRef’ keyword



Optional

The ‘Optional’ keyword



ParamArray

The ‘ParamArray’ keyword



Public

The ‘Public’ keyword



Private

The ‘Private’ keyword



Protected

The ‘Protected’ keyword



Friend

The ‘Friend’ keyword



ProtectedFriend

The ‘ProtectedFriend’ keyword



Shared

The ‘Shared’ keyword



MustInherit

The ‘MustInherit’ keyword



NotInheritable

The ‘NotInheritable’ keyword



MustOverride

The ‘MustOverride’ keyword



Overridable

The ‘Overridable’ keyword



Overrides

The ‘Overrides’ keyword



NotOverridable

The ‘NotOverridable’ keyword



MustOverrideReadOnly

The ‘MustOverrideReadOnly’ keyword



ReadOnly

The ‘ReadOnly’ keyword



WriteOnly

The ‘WriteOnly’ keyword



Static

The ‘Static’ keyword



Partial

The ‘Partial’ keyword



Async

The ‘Async’ keyword



Await

The ‘Await’ keyword



From

The ‘From’ keyword for LINQ



Where

The ‘Where’ keyword for LINQ



Order

The ‘Order’ keyword for LINQ



By

The ‘By’ keyword for LINQ



Group

The ‘Group’ keyword for LINQ



Join

The ‘Join’ keyword for LINQ



On

The ‘On’ keyword for LINQ



Into

The ‘Into’ keyword for LINQ



Let

The ‘Let’ keyword for LINQ



Overloads

The ‘Overloads’ keyword



Inherits

The ‘Inherits’ keyword



Implements

The ‘Implements’ keyword



Get

The ‘Get’ keyword



Set

The ‘Set’ keyword



Equals

The ‘Equals’ keyword



Statement

The ‘Statement’ keyword



Plus

The ‘+’ operator



Minus

The ‘-’ operator



Star

The ‘*’ operator



Slash

The ‘/’ operator



Backslash

The ’' operator



Percent

The ‘%’ operator



Caret

The ‘^’ operator



Equal

The ‘=’ operator



NotEqual

The ‘<>’ operator



LessThan

The ‘<’ operator



LessEqual

The ‘<=’ operator



GreaterThan

The ‘>’ operator



GreaterEqual

The ‘>=’ operator



And

The ‘And’ operator



Or

The ‘Or’ operator



Not

The ‘Not’ operator



Xor

The ‘Xor’ operator



AndAlso

The ‘AndAlso’ operator



OrElse

The ‘OrElse’ operator



Is

The ‘Is’ operator



IsNot

The ‘IsNot’ operator



Like

The ‘Like’ operator



TypeOf

The ‘TypeOf’ operator



LeftParen

The ‘(’ delimiter



RightParen

The ‘)’ delimiter



LeftBracket

The ‘[’ delimiter



RightBracket

The ‘]’ delimiter



LeftBrace

The ‘{’ delimiter



RightBrace

The ‘}’ delimiter



Comma

The ‘,’ punctuation



Semicolon

The ‘;’ punctuation



Colon

The ‘:’ punctuation



Dot

The ‘.’ punctuation



Exclamation

The ‘!’ punctuation



Hash

The ‘#’ punctuation



Ampersand

The ‘&’ punctuation



LineComment

Line comment



BlockComment

Block comment



Error

Error



Eof

End of file

Implementations

Source

impl VbNetTokenType

pub fn is_keyword(&self) -> bool

Checks if it is a keyword