VbNetElementType

Enum VbNetElementType 

pub enum VbNetElementType {
Show 60 variants Root, Expression, Whitespace, Newline, Identifier, IntegerLiteral, FloatLiteral, StringLiteral, CharLiteral, BooleanLiteral, DateLiteral, NothingLiteral, Namespace, Imports, Class, Interface, Structure, Enum, Module, Delegate, Event, Function, Sub, Property, Variable, If, For, ForEach, While, DoWhile, SelectCase, With, Try, Catch, Finally, Dim, Const, Return, Exit, Continue, Statement, Throw, BinaryExpression, UnaryExpression, AssignmentExpression, MethodCall, MemberAccess, ElementAccess, NewExpression, ArrayExpression, TupleExpression, ParenthesizedExpression, TypeOfExpression, IsExpression, LikeExpression, IfExpression, LambdaExpression, XmlLiteral, Error, Eof,
}
VB.NET element types

Variants



Root

Root node



Expression

Expression



Whitespace

Whitespace



Newline

Newline



Identifier

Identifier



IntegerLiteral

Integer literal



FloatLiteral

Float literal



StringLiteral

String literal



CharLiteral

Character literal



BooleanLiteral

Boolean literal



DateLiteral

Date literal



NothingLiteral

Nothing literal



Namespace

Namespace declaration



Imports

Imports directive



Class

Class declaration



Interface

Interface declaration



Structure

Structure declaration



Enum

Enum declaration



Module

Module declaration



Delegate

Delegate declaration



Event

Event declaration



Function

Function declaration



Sub

Subroutine declaration



Property

Property declaration



Variable

Variable declaration



If

If statement



For

For loop



ForEach

For Each loop



While

While loop



DoWhile

Do While loop



SelectCase

Select Case statement



With

With statement



Try

Try statement



Catch

Catch clause



Finally

Finally block



Dim

Dim statement



Const

Const statement



Return

Return statement



Exit

Exit statement



Continue

Continue statement



Statement

Statement



Throw

Throw statement



BinaryExpression

Binary expression



UnaryExpression

Unary expression



AssignmentExpression

Assignment expression



MethodCall

Method call



MemberAccess

Member access



ElementAccess

Element access



NewExpression

New expression



ArrayExpression

Array expression



TupleExpression

Tuple expression



ParenthesizedExpression

Parenthesized expression



TypeOfExpression

TypeOf expression



IsExpression

Is expression



LikeExpression

Like expression



IfExpression

If expression



LambdaExpression

Lambda expression



XmlLiteral

XML literal



Error

Error



Eof

End of file

Implementations

Source

impl VbNetElementType

pub fn is_keyword(&self) -> bool

Checks if it is a keyword