pub fn parse(source: &str) -> Result<VbNetRoot, OakError>Expand description
Parses VB.NET source code into a VbNetRoot AST.
This is a convenience function that initializes the language, builder, and parser to process the source text.
Errors
Returns an oak_core::OakError if parsing fails.